@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2025 Vaclav Slavik
+ *  Copyright (C) 1999-2026 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -189,31 +189,6 @@ wxTextFileType GetDesiredCRLFFormat(wxTextFileType existingCRLF)
     }
 }
 
-
-unsigned GetCountFromPluralFormsHeader(const Catalog::HeaderData& header)
-{
-    if ( header.HasHeader("Plural-Forms") )
-    {
-        // e.g. "Plural-Forms: nplurals=3; plural=(n%10==1 && n%100!=11 ?
-        //       0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);\n"
-
-        wxString form = header.GetHeader("Plural-Forms");
-        form = form.BeforeFirst(_T(';'));
-        if (form.BeforeFirst(_T('=')) == "nplurals")
-        {
-            wxString vals = form.AfterFirst('=');
-            if (vals == "INTEGER") // POT default
-                return 2;
-            long val;
-            if (vals.ToLong(&val))
-                return (unsigned)val;
-        }
-    }
-
-    // fallback value for plural forms count should be 2, as in English:
-    return 2;
-}
-
 } // anonymous namespace
 
 
@@ -224,6 +199,7 @@ unsigned GetCountFromPluralFormsHeader(const Catalog::HeaderData& header)
 bool POCatalogParser::Parse()
 {
     static const wxString prefix_flags(wxS("#, "));
+    static const wxString prefix_flags_alt(wxS("#= "));
     static const wxString prefix_autocomments(wxS("#. "));
     static const wxString prefix_autocomments2(wxS("#.")); // account for empty auto comments
     static const wxString prefix_references(wxS("#: "));
@@ -249,26 +225,30 @@ bool POCatalogParser::Parse()
     unsigned mlinenum = 0;
 
     line = m_textFile->GetFirstLine();
-    if (line.empty()) line = ReadTextLine();
+    if (line.empty())
+        line = ReadTextLine();
 
     while (!line.empty())
     {
         // ignore empty special tags (except for extracted comments which we
         // DO want to preserve):
-        while (line.length() == 2 && *line.begin() == '#' && (line[1] == ',' || line[1] == ':' || line[1] == '|'))
+        while (line.length() == 2 && *line.begin() == '#' && (line[1] == ',' || line[1] == '=' || line[1] == ':' || line[1] == '|'))
             line = ReadTextLine();
 
         // flags:
-        // Can't we have more than one flag, now only the last is kept ...
-        if (ReadParam(line, prefix_flags, dummy))
+        if (ReadParam(line, prefix_flags, dummy) || ReadParam(line, prefix_flags_alt, dummy))
         {
+            // see https://lists.gnu.org/archive/html/bug-gettext/2025-06/msg00018.html for introduction of
+            // the #= alt form. We currently take the approach of converting #= to #, on write, as msgcat
+            // also does, but this is just the initial, interim implementation
             static wxString prefix_flags_partial(wxS(", "));
-            mflags = prefix_flags_partial + dummy;
+            mflags += prefix_flags_partial;
+            mflags += dummy;
             line = ReadTextLine();
         }
 
         // auto comments:
-        if (ReadParam(line, prefix_autocomments, dummy, /*preserveWhitespace=*/true) || ReadParam(line, prefix_autocomments2, dummy, /*preserveWhitespace=*/true))
+        else if (ReadParam(line, prefix_autocomments, dummy, /*preserveWhitespace=*/true) || ReadParam(line, prefix_autocomments2, dummy, /*preserveWhitespace=*/true))
         {
             mextractedcomments.Add(dummy);
             line = ReadTextLine();
@@ -986,6 +966,7 @@ void POCatalog::FixupCommonIssues()
     // In PHP use, strings with % (typically: 100%) get frequently mis-identified as php-format, because the
     // format string allows space, so e.g. "100% complete" has a valid "% c" format flag in it. Work around
     // this by removing the flag ourselves, as translators can rarely influence it:
+    // TODO: This shouldn't be much of an issue once gettext-0.26 gets wider adoption
     for (auto& i: items())
     {
         if (i->GetFormatFlag() == "php")
@@ -1485,7 +1466,7 @@ bool POCatalog::DoSaveOnly(wxTextBuffer& f, wxTextFileType crlf)
     SaveMultiLines(f, pohdr);
     f.AddLine(wxEmptyString);
 
-    auto pluralsCount = GetPluralFormsCount();
+    auto pluralsCount = std::max(GetPluralFormsCountPresentInItems(), GetPluralForms().nplurals());
 
     for (auto& data_: m_items)
     {
@@ -1589,26 +1570,30 @@ void POCatalog::SetLanguage(Language lang)
         m_header.SetHeaderNotEmpty("Plural-Forms", lang.DefaultPluralFormsExpr().str());
 }
 
-unsigned POCatalog::GetPluralFormsCount() const
+PluralFormsExpr POCatalog::GetPluralForms() const
 {
-    return std::max(GetCountFromPluralFormsHeader(m_header), Catalog::GetPluralFormsCount());
+    if (!m_header.HasHeader("Plural-Forms"))
+        return PluralFormsExpr::English();
+
+    auto hdr = m_header.GetHeader("Plural-Forms");
+    if (hdr.Contains("INTEGER"))
+    {
+        // header has POT default value, assume English because that's all we can do
+        return PluralFormsExpr::English();
+    }
+
+    return PluralFormsExpr(str::to_utf8(hdr));
 }
 
 bool POCatalog::HasWrongPluralFormsCount() const
 {
-    unsigned count = 0;
-
-    for (auto& i: m_items)
-    {
-        count = std::max(count, i->GetPluralFormsCount());
-    }
-
+    unsigned count = GetPluralFormsCountPresentInItems();
     if ( count == 0 )
         return false; // nothing translated, so we can't tell
 
     // if 'count' is less than the count from header, it may simply mean there
     // are untranslated strings
-    if ( count > GetCountFromPluralFormsHeader(m_header) )
+    if ( count > GetPluralForms().nplurals() )
         return true;
 
     return false;
