@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2015-2025 Vaclav Slavik
+ *  Copyright (C) 2015-2026 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -25,6 +25,7 @@
 
 #include "customcontrols.h"
 
+#include "edapp.h"
 #include "concurrency.h"
 #include "errors.h"
 #include "hidpi.h"
@@ -371,6 +372,19 @@ bool LearnMoreLinkXmlHandler::CanHandle(wxXmlNode *node)
 }
 
 
+#ifdef __WXOSX__
+HelpButton::HelpButton(wxWindow *parent, const wxString& helpPage) : wxButton(parent, wxID_HELP)
+{
+    Bind(wxEVT_BUTTON, [=](wxCommandEvent&){ wxGetApp().OpenPoeditWeb(helpPage); });
+}
+#else
+HelpButton::HelpButton(wxWindow *parent, const wxString& helpPage) : LearnMoreLink(parent, "", _("Help"))
+{
+    Bind(wxEVT_HYPERLINK, [=](wxHyperlinkEvent&){ wxGetApp().OpenPoeditWeb(helpPage); });
+}
+#endif
+
+
 ActivityIndicator::ActivityIndicator(wxWindow *parent, int flags)
     : wxWindow(parent, wxID_ANY), m_running(false)
 {
