@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2014-2025 Vaclav Slavik
+ *  Copyright (C) 2014-2026 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -136,14 +136,6 @@ class ExplanationLabel : public AutoWrappingText
 public:
     ExplanationLabel(wxWindow *parent, const wxString& label);
 
-#if defined(__WXOSX__)
-    static const int CHECKBOX_INDENT = 21;
-#elif defined(__WXMSW__)
-    static const int CHECKBOX_INDENT = 17;
-#elif defined(__WXGTK__)
-    static const int CHECKBOX_INDENT = 25;
-#endif
-
     static wxColour GetTextColor() { return ColorScheme::Get(Color::SecondaryLabel); }
 };
 
@@ -173,6 +165,18 @@ public:
 };
 
 
+class HelpButton
+#ifdef __WXOSX__
+    : public wxButton
+#else
+    : public LearnMoreLink
+#endif
+{
+public:
+    HelpButton(wxWindow *parent, const wxString& helpPage);
+};
+
+
 /// Indicator of background activity, using spinners where appropriate.
 class ActivityIndicator : public wxWindow
 {
