@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2025 Vaclav Slavik
+ *  Copyright (C) 1999-2026 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -1222,7 +1222,7 @@ void PoeditApp::OnAbout(wxCommandEvent&)
     about.SetVersion(wxGetApp().GetAppVersion());
     about.SetDescription(_("Poedit is an easy to use translation editor."));
 #endif
-    about.SetCopyright(L"Copyright \u00a9 1999-2025 Václav Slavík");
+    about.SetCopyright(L"Copyright \u00a9 1999-2026 Václav Slavík");
 #ifdef __WXGTK__ // other ports would show non-native about dlg
     about.SetWebSite("https://poedit.net");
     about.SetIcon(wxArtProvider::GetIcon("net.poedit.Poedit", wxART_FRAME_ICON, wxSize(128, 128)));
@@ -1326,12 +1326,12 @@ void PoeditApp::OnPreferences(wxCommandEvent&)
 
 void PoeditApp::OnHelp(wxCommandEvent&)
 {
-    OpenPoeditWeb("/trac/wiki/Doc");
+    OpenPoeditWeb("/help/index");
 }
 
 void PoeditApp::OnGettextManual(wxCommandEvent&)
 {
-    wxLaunchDefaultBrowser("https://www.gnu.org/software/gettext/manual/html_node/");
+    OpenPoeditWeb("/help/gnu-gettext");
 }
 
 
