@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 1999-2025 Vaclav Slavik
+ *  Copyright (C) 1999-2026 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
@@ -650,7 +650,7 @@ void PoeditListCtrl::CreateColumns()
     m_colID = m_colIcon = m_colSource = m_colTrans = nullptr;
 
 #if defined(__WXMSW__)
-    int iconWidth = wxArtProvider::GetBitmap("StatusError").GetSize().x + 6 /*wxDVC internal padding*/;
+    int iconWidth = wxArtProvider::GetBitmap("StatusError").GetSize().x + FromDIP(6) /*wxDVC internal padding*/;
 #else
     int iconWidth = PX(16);
 #endif
@@ -850,6 +850,8 @@ void PoeditListCtrl::CatalogChanged(const CatalogPtr& catalog)
 
     if (sizeOrCatalogChanged && GetItemCount() > 0)
         CallAfter([=]{ SelectAndFocus(0); });
+
+    Refresh();
 }
 
 
