@@ -1,7 +1,7 @@
 /*
  *  This file is part of Poedit (https://poedit.net)
  *
- *  Copyright (C) 2013-2025 Vaclav Slavik
+ *  Copyright (C) 2013-2026 Vaclav Slavik
  *
  *  Permission is hereby granted, free of charge, to any person obtaining a
  *  copy of this software and associated documentation files (the "Software"),
@@ -96,7 +96,7 @@ void TryNormalize(std::wstring& s)
     }
 }
 
-bool IsISOLanguage(const std::string& s)
+bool IsValidLanguage(const std::string& s)
 {
     const char *test = s.c_str();
     for (const char * const* i = uloc_getISOLanguages(); *i != nullptr; ++i)
@@ -107,7 +107,7 @@ bool IsISOLanguage(const std::string& s)
     return false;
 }
 
-bool IsISOCountry(const std::string& s)
+bool IsValidRegion(const std::string& s)
 {
     const char *test = s.c_str();
     for (const char * const* i = uloc_getISOCountries(); *i != nullptr; ++i)
@@ -115,6 +115,11 @@ bool IsISOCountry(const std::string& s)
         if (strcmp(test, *i) == 0)
             return true;
     }
+
+    // accept UN M.49 codes for Latin America (used in practice) and World+Europe (extremely rarely used)
+    if (s == "419" || s == "001" || s == "015")
+        return true;
+
     return false;
 }
 
@@ -436,11 +441,11 @@ Language Language::TryParseWithValidation(const std::wstring& s)
     if (!lang.IsValid())
         return Language(); // invalid
 
-    if (!IsISOLanguage(lang.Lang()))
+    if (!IsValidLanguage(lang.Lang()))
         return Language(); // invalid
 
     auto country = lang.Country();
-    if (!country.empty() && !IsISOCountry(country))
+    if (!country.empty() && !IsValidRegion(country))
         return Language(); // invalid
 
     return lang;
@@ -663,37 +668,38 @@ Language Language::TryGuessFromFilename(const wxString& filename, wxString *wild
     auto dirs = fn.GetDirs();
     if (!dirs.empty())
     {
-        size_t i = dirs.size() - 1;
-        if (dirs[i].IsSameAs("LC_MESSAGES", /*caseSensitive=*/false))
+        for (size_t i = dirs.size() - 1; i > 0; --i)
         {
-            if (i == 0)
-                return Language(); // failed to match
-            --i;
-        }
-        wxString rest, wmatch;
-        if (dirs[i].EndsWith(".lproj", &rest))
-        {
-            auto l = rest.ToStdWstring();
-            if (Language::IsPlausibleCode(l))
-                lang = Language::TryParseWithValidation(l);
-            wmatch = "*.lproj";
-        }
-        else
-        {
-            auto l = dirs[i].ToStdWstring();
-            if (Language::IsPlausibleCode(l))
-                lang = Language::TryParseWithValidation(l);
-            wmatch = "*";
-        }
-        if (lang.IsValid())
-        {
-            if (wildcard)
+            if (dirs[i].IsSameAs("LC_MESSAGES", /*caseSensitive=*/false))
             {
-                fn.RemoveDir(i);
-                fn.InsertDir(i, wmatch);
-                *wildcard = fn.GetFullPath();
+                // common setup in gettext world: $lang/LC_MESSAGES/file.mo
+                continue;
+            }
+            wxString rest, wmatch;
+            if (dirs[i].EndsWith(".lproj", &rest))
+            {
+                auto l = rest.ToStdWstring();
+                if (Language::IsPlausibleCode(l))
+                    lang = Language::TryParseWithValidation(l);
+                wmatch = "*.lproj";
+            }
+            else
+            {
+                auto l = dirs[i].ToStdWstring();
+                if (Language::IsPlausibleCode(l))
+                    lang = Language::TryParseWithValidation(l);
+                wmatch = "*";
+            }
+            if (lang.IsValid())
+            {
+                if (wildcard)
+                {
+                    fn.RemoveDir(i);
+                    fn.InsertDir(i, wmatch);
+                    *wildcard = fn.GetFullPath();
+                }
+                return lang;
             }
-            return lang;
         }
     }
 
